@@ -189,6 +189,7 @@ void row_selected (void)
                 g_string_append (statusbar_msg, _("Action and option selected   "));
             }
             if (at_least_one_prompt_command_startupnotify_selected && at_least_one_enabled_name_wmclass_icon_selected) {
+				// Translation note: Do not translate "startupnotify"
                 g_string_append (statusbar_msg, _("Action option and startupnotify option selected   "));
             }
             if (at_least_one_option_more_than_once_selected) {
@@ -198,6 +199,7 @@ void row_selected (void)
             if (!(*statusbar_msg->str)) { // -> selected_row_has_selected_dsct = TRUE
                 g_string_append (statusbar_msg, _("Row and descendant of it selected   "));
             }
+            // Translation note: This refers to a drag and drop operation
             g_string_prepend (statusbar_msg, _("Dragging disabled --- "));
             show_msg_in_statusbar (statusbar_msg->str);
 
@@ -335,6 +337,7 @@ void row_selected (void)
     gtk_widget_set_sensitive (ks.tb_buttons[TB_BUTTON_NEW], (!treestore_is_empty || ks.change_done));
     gtk_widget_set_sensitive (ks.tb_buttons[TB_BUTTON_SAVE], (ks.filename && ks.change_done));
 
+    // Translation note: the verb "Save"
     g_autoptr(GString) save_menu_tooltip = g_string_new (_("Save Menu"));
     if (G_UNLIKELY (ks.pos_inside_undo_stack == 1 && ks.number_of_undo_stack_items == 1)) {
         gboolean edit_done_during_loading = (ks.loading_process_edit_types[ICON_INFO_CORRECTED] || 
@@ -347,7 +350,9 @@ void row_selected (void)
 
         gchar *save_menu_tooltip_txts[] = { N_("At least one incorrect icon path or format has been corrected"), 
                                             N_("At least one incorrect option value has been corrected"), 
+											// Translation note: "Visualize" in the sense of making something visible
                                             N_("At least one invisible menu element has been visualized or removed"), 
+											// Translation note: Do not translate "execute"
                                             N_("At least one \"execute\" option has been converted") };
 
         for (corrections_cnt = 0; corrections_cnt < NUMBER_OF_LOADING_PROCESS_EDIT_TYPES; ++corrections_cnt) {
@@ -625,12 +630,18 @@ void row_selected (void)
             (STREQ (ks.txt_fields[TYPE_TXT], "option block") && number_of_children_of_iter == NUMBER_OF_STARTUPNOTIFY_OPTS)) {
             // All options of "Execute" are set.
             if (number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS) {
+				// Translation note: Do not translate "Execute"
                 all_options_have_been_set_msg (_(" All Options for This Execute Action Have Been Set"));
             }
             // One option of "Execute" is not set.
             else if (number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS - 1) {
                 gboolean execute_options_status[NUMBER_OF_EXECUTE_OPTS] = { 0 };
-                const gchar *execute_opts_with_mnemonic[] = { N_("_Prompt"), N_("_Command"), _("Startup_notify") };
+                const gchar *execute_opts_with_mnemonic[] = { // Translation note: Do not translate
+				                                              N_("_Prompt"),
+															  // Translation note: Do not translate
+				                                              N_("_Command"), 
+															  // Translation note: Do not translate
+															  _("Startup_notify") };
 
                 check_for_existing_options (&parent, NUMBER_OF_EXECUTE_OPTS, ks.execute_options, execute_options_status);
 
@@ -653,6 +664,7 @@ void row_selected (void)
                 number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS) || 
                 (STREQ (ks.txt_fields[TYPE_TXT], "option") && 
                 number_of_children_of_parent == NUMBER_OF_STARTUPNOTIFY_OPTS)) {
+				// Translation note: Do not translate "Startupnotify"
                 all_options_have_been_set_msg (_(" All Options for This Startupnotify Option Block Have Been Set"));
             }
             // "startupnotify" option block or option of it selected and one option of "startupnotify" not set.
@@ -662,7 +674,14 @@ void row_selected (void)
                      (STREQ (ks.txt_fields[TYPE_TXT], "option") && 
                      number_of_children_of_parent == NUMBER_OF_STARTUPNOTIFY_OPTS - 1)) {
                 gboolean startupnotify_options_status[NUMBER_OF_STARTUPNOTIFY_OPTS] = { 0 };
-                const gchar *startupnotify_opts_with_mnemonic[] = { N_("E_nabled"), N_("_Name"), N_("_WM__CLASS"), N_("_Icon") };
+                const gchar *startupnotify_opts_with_mnemonic[] = { // Translation note: Do not translate
+				                                                    N_("E_nabled"), 
+																	// Translation note: Do not translate
+				                                                    N_("_Name"), 
+																	// Translation note: Do not translate
+																	N_("_WM__CLASS"), 
+																	// Translation note: Do not translate
+																	N_("_Icon") };
 
                 if (STREQ (ks.txt_fields[TYPE_TXT], "option block")) {
                     parent = ks.iter;
@@ -692,12 +711,15 @@ void row_selected (void)
             const gchar *msg_label_txt;
 
             if (STREQ (menu_element_txt_parent, "Exit")) {
+				// Translation note: Do not translate "Exit"
                 msg_label_txt = _(" All Options for This Exit Action Have Been Set");
             }
             else if (STREQ (menu_element_txt_parent, "Restart")) {
+				// Translation note: Do not translate "Restart"
                 msg_label_txt = _(" All Options for This Restart Action Have Been Set");
             }
             else { // SessionLogout
+			    // Translation note: Do not translate "SessionLogout"
                 msg_label_txt = _(" All Options for This SessionLogout Action Have Been Set");
             }
 
